@@ -25,8 +25,8 @@ class CloneMixin(object):
     :type _clone_fields`collections.Iterable`
     :param _clone_m2m_fields: Many to many fields (Example: TestModel.tags).
     :type _clone_m2m_fields`collections.Iterable`
-    :param _clone_m2m_or_o2m_fields: Many to one/One to many fields.
-    :type _clone_m2m_or_o2m_fields`collections.Iterable`
+    :param _clone_m2o_or_o2m_fields: Many to one/One to many fields.
+    :type _clone_m2o_or_o2m_fields`collections.Iterable`
     :param _clone_o2o_fields: One to One fields.
     :type _clone_o2o_fields`collections.Iterable`
 
@@ -53,7 +53,7 @@ class CloneMixin(object):
     >>>     )
 
     >>>     _clone_m2m_fields = ['tags', 'audiences']
-    >>>     _clone_m2m_or_o2m_fields = ['user']
+    >>>     _clone_m2o_or_o2m_fields = ['user']
     >>>     ...
 
     >>> # Using implicit all except fields.
@@ -78,7 +78,7 @@ class CloneMixin(object):
     # Included fields
     _clone_fields = []
     _clone_m2m_fields = []
-    _clone_m2m_or_o2m_fields = []
+    _clone_m2o_or_o2m_fields = []
     _clone_o2o_fields = []
 
     # Excluded fields
@@ -236,7 +236,7 @@ class CloneMixin(object):
 
         if all(
             [
-                cls._clone_m2m_or_o2m_fields,
+                cls._clone_m2o_or_o2m_fields,
                 cls._clone_excluded_m2o_or_o2m_fields,
             ]
         ):
@@ -245,10 +245,11 @@ class CloneMixin(object):
                     "Conflicting configuration.",
                     hint=(
                         "Please provide either "
-                        + '"_clone_m2m_or_o2m_fields"'
+                        + '"_clone_m2o_or_o2m_fields"'
                         + " or "
-                        + '"_clone_excluded_many_to_one'
-                        + '_or_one_to_many_fields" for {}'.format(cls.__name__)
+                        + '"_clone_excluded_m2o_or_o2m_fields" for {}'.format(
+                            cls.__name__
+                        )
                     ),
                     obj=cls,
                     id="{}.E002".format(ModelCloneConfig.name),
@@ -320,14 +321,14 @@ class CloneMixin(object):
             elif all(
                 [
                     any([f.many_to_one, f.one_to_many]),
-                    f.name in self._clone_m2m_or_o2m_fields,
+                    f.name in self._clone_m2o_or_o2m_fields,
                 ]
             ):
                 many_to_one_or_one_to_many_fields.append(f)
 
             elif all(
                 [
-                    not self._clone_m2m_or_o2m_fields,
+                    not self._clone_m2o_or_o2m_fields,
                     any([f.many_to_one, f.one_to_many]),
                     self._clone_excluded_m2o_or_o2m_fields,
                     f not in many_to_one_or_one_to_many_fields,
